@@ -152,6 +152,8 @@ private:
 
     void set_real_library_path (const UString &a_path) ;
 
+    void set_name (const UString &a_name) ;
+
     void set_module_loader (Loader *a_loader) ;
 
 
@@ -166,6 +168,9 @@ public:
     /// \return the path of the library the module has been instanciated from.
     const UString& get_real_library_path () const ;
 
+    /// \brief gets the (short) name of this dynmod
+    const UString& get_name () const;
+
     /// \brief destructor
     virtual ~DynamicModule () ;
 
@@ -201,7 +206,9 @@ public:
             return false ;
         }
         typedef SafePtr<T, ObjectRef, ObjectUnref> TSafePtr ;
-        TSafePtr res = iface.do_dynamic_cast<T> () ;
+        // Here, the 'template' keyword is useless, stricto sensu.
+        // But we need it to keep gcc 3.3.5 happy.
+        TSafePtr res = iface.template do_dynamic_cast<T> () ;
         if (!res) {
             return false ;
         }
@@ -334,7 +341,9 @@ DynamicModuleManager::load_iface (const UString &a_module_name,
     THROW_IF_FAIL (tmp_iface) ;
     LOG_REF_COUNT (module, a_module_name) ;
     TSafePtr result ;
-    result = tmp_iface.do_dynamic_cast<T> ();
+    // Here, the 'template' keyword is useless, stricto sensu.
+    // But we need it to keep gcc 3.3.5 happy.
+    result = tmp_iface.template do_dynamic_cast<T> ();
     LOG_REF_COUNT (module, a_module_name) ;
     if (!result) {
         THROW (UString ("interface named ")
@@ -386,6 +395,40 @@ DynamicModuleManager::load_iface_with_default_manager
     return get_default_manager ().load_iface<T> (a_mod_name, a_iface_name) ;
 }
 
+/// This is a shortcut method to load an interface
+/// using the same module_manager that was used to load
+/// a_iface.
+template<class T>
+SafePtr<T, ObjectRef, ObjectUnref>
+load_iface_using_context (DynModIface &a_iface,
+                          const UString &a_iface_name)
+{
+    DynamicModuleManager *manager =
+        a_iface.get_dynamic_module ().get_module_loader ()
+                                    ->get_dynamic_module_manager ();
+    THROW_IF_FAIL (manager);
+    SafePtr<T, ObjectRef, ObjectUnref> iface =
+        manager->load_iface<T> (a_iface.get_dynamic_module ().get_name (),
+                                a_iface_name);
+    THROW_IF_FAIL (iface);
+    return iface;
+}
+
+template<class T>
+SafePtr<T, ObjectRef, ObjectUnref>
+load_iface_using_context (DynamicModule &a_dynmod,
+                          const UString &a_iface_name)
+{
+    DynamicModuleManager *manager =
+        a_dynmod.get_module_loader () ->get_dynamic_module_manager ();
+
+    THROW_IF_FAIL (manager);
+    SafePtr<T, ObjectRef, ObjectUnref> iface =
+        manager->load_iface<T> (a_dynmod.get_name (), a_iface_name);
+    THROW_IF_FAIL (iface);
+    return iface;
+}
+
 NEMIVER_END_NAMESPACE (common)
 NEMIVER_END_NAMESPACE (nemiver)
 
