@@ -15,7 +15,7 @@
  *See the GNU General Public License for more details.
  *
  *You should have received a copy of the
- *GNU General Public License along with Goupil;
+ *GNU General Public License along with Nemiver;
  *see the file COPYING.
  *If not, write to the Free Software Foundation,
  *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -27,8 +27,8 @@
 
 #include <gtkmm.h>
 #include <list>
-#include "nmv-api-macros.h"
-#include "nmv-plugin.h"
+#include "common/nmv-api-macros.h"
+#include "common/nmv-plugin.h"
 #include "nmv-i-workbench.h"
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
@@ -55,9 +55,13 @@ class NEMIVER_API IPerspective : public Plugin::EntryPoint {
     //non copyable
     IPerspective (const IPerspective&) ;
     IPerspective& operator= (const IPerspective&) ;
+    IPerspective () ;
 
 protected:
-    IPerspective () {}
+    IPerspective (DynamicModule *a_dynmod) :
+        Plugin::EntryPoint (a_dynmod)
+    {
+    }
 
 public:
 
@@ -82,6 +86,9 @@ public:
     /// \returns the body of the perspective.
     virtual Gtk::Widget* get_body () = 0 ;
 
+    /// \returns the workbench associated to this perspective
+    virtual IWorkbench& get_workbench () = 0;
+
     /// This method is only called once, during the
     /// perspective's initialisation time,
     /// by the workbench.
@@ -106,6 +113,14 @@ public:
     /// \param a_uri the uri that identifies the file to close
     virtual void close_file (const UString &a_uri) = 0;
 
+    /// \brief load a menu file
+    /// \param a_filename the file name of the menu file.
+    ///  It's relative to the "menus" subdirectory of the perspective
+    ///  \param a_widget_name the name of the widget to return as the root
+    ///  of the menu.
+    virtual Gtk::Widget* load_menu (const UString &a_filename,
+                                    const UString &a_widget_name) = 0;
+
     /// \name signals
 
     /// @{
